@@ -23,13 +23,14 @@
 #' @examples 
 #' require(gnrprod)
 #' data <- colombian
+#' \dontrun{
 #' industry_311_flex <- gnrflex(output = "RGO", fixed = c("L", "K"),
 #'                              flex = "RI", share = "share", id = "id",
 #'                              time = "year", data = data,
 #'                              control = list(degree_w = 2, maxit = 200))
 #' 
 #' industry_311_fixed <- gnriv(industry_311_flex,
-#'                             control = list(trace = 1))
+#'                             control = list(trace = 1))}
 #' @importFrom data.table "data.table"
 #' @importFrom data.table ".SD"
 #' @importFrom data.table "shift"
@@ -59,8 +60,8 @@ gnriv <- function(object, control, ...) {
   degree_tau <- ctrl[[2]]
   method <- ctrl[[3]]
   
-  if (degree_w <= 0) {
-    degree_w <- object$control$degree
+  if (degree_tau <= 0) {
+    degree_tau <- object$control$degree
   }
   
   if (degree_tau == object$control$degree) {
@@ -185,12 +186,16 @@ constant_moments <- function(C_kl, data, big_Y_base, big_Y_lag, lag_data,
                              degree) {
   w <- big_Y_base - (data %*% C_kl)
   w_1 <- big_Y_lag - (lag_data %*% C_kl)
-
-  poly <- sapply(2:degree, FUN = function(i) {
-    `^`(w_1, i)
-  })
-
-  markov <- cbind(w_1, poly)
+  
+  if (degree < 2) {
+    markov <- w_1
+  } else {
+    poly <- sapply(2:degree, FUN = function(i) {
+      `^`(w_1, i)
+    })
+    
+    markov <- cbind(w_1, poly)
+  }
 
   reg <- stats::lm(w ~ markov)
   csi <- w - reg$fitted.values
